@@ -29,3 +29,12 @@ class ParseError(Error):
 @dataclass
 class ExtractError(Error):
     pass
+
+
+@dataclass
+class InsufficientEncodingDetectorConfidenceError(Exception):
+    def __init__(self, confidence_threshold: float):
+        self.message = (
+            f"The confidence returned by the encoding detector was"
+            f" less than the threshold {confidence_threshold}."
+        )
